@@ -1,9 +1,9 @@
 package WWW::PAUSE::Simple;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-09-18'; # DATE
+our $DATE = '2020-09-21'; # DATE
 our $DIST = 'WWW-PAUSE-Simple'; # DIST
-our $VERSION = '0.448'; # VERSION
+our $VERSION = '0.449'; # VERSION
 
 use 5.010001;
 use strict;
@@ -597,8 +597,8 @@ Currently does not look for releases in subdirectories.
 By default does not include developer (trial) releases. To include that, use
 `--include-dev`.
 
-To only cleanup developer deleases, you can use `--exclude-dev` and
-`--include-nondev`.
+To only cleanup developer releases, you can use `--include-dev` and
+`--exclude-nondev`.
 
 _
     args => {
@@ -957,7 +957,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.448 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2020-09-18.
+This document describes version 0.449 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2020-09-21.
 
 =head1 SYNOPSIS
 
@@ -1058,8 +1058,8 @@ Currently does not look for releases in subdirectories.
 By default does not include developer (trial) releases. To include that, use
 C<--include-dev>.
 
-To only cleanup developer deleases, you can use C<--exclude-dev> and
-C<--include-nondev>.
+To only cleanup developer releases, you can use C<--include-dev> and
+C<--exclude-nondev>.
 
 This function is not exported by default, but exportable.
 
